@@ -39,8 +39,12 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <knewstuff_version.h>
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 78, 0)
 #include <KNS3/DownloadDialog>
-#include <kns3/knewstuffaction.h>
+#else
+#include <KNS3/QtQuickDialogWrapper>
+#endif
 #include <KNotifyConfigWidget>
 #include <KPageWidget>
 #include <KProcess>
@@ -123,8 +127,10 @@ void KWordQuizApp::initActions()
 
   fileOpenRecent = KStandardAction::openRecent(this, SLOT(slotFileOpenRecent(QUrl)), actionCollection());
 
-  fileGHNS = KNS3::standardAction(i18n("Download New Vocabularies..."), this, SLOT(slotFileGHNS()), actionCollection(), "file_ghns");
-  actionCollection()->setDefaultShortcut(fileGHNS, QKeySequence(Qt::CTRL + Qt::Key_G));
+  fileGHNS = new QAction(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")), i18n("Download New Vocabularies..."), this);
+  connect(fileGHNS, &QAction::triggered, this, &KWordQuizApp::slotFileGHNS);
+  actionCollection()->addAction(QStringLiteral("file_ghns"), fileGHNS);
+  actionCollection()->setDefaultShortcut(fileGHNS, QKeySequence(Qt::CTRL | Qt::Key_G));
   fileGHNS->setWhatsThis(i18n("Downloads new vocabularies"));
   fileGHNS->setToolTip(fileGHNS->whatsThis());
   fileGHNS->setStatusTip(fileGHNS->whatsThis());
@@ -189,7 +195,7 @@ void KWordQuizApp::initActions()
   editInsert = actionCollection()->addAction(QStringLiteral("edit_insert"));
   editInsert->setIcon(QIcon::fromTheme(QStringLiteral("insert-table-row")));
   editInsert->setText(i18n("&Insert Row"));
-  actionCollection()->setDefaultShortcut(editInsert, QKeySequence(Qt::CTRL + Qt::Key_I));
+  actionCollection()->setDefaultShortcut(editInsert, QKeySequence(Qt::CTRL | Qt::Key_I));
   editInsert->setWhatsThis(i18n("Inserts a new row above the current row"));
   editInsert->setToolTip(editInsert->whatsThis());
   editInsert->setStatusTip(editInsert->whatsThis());
@@ -198,7 +204,7 @@ void KWordQuizApp::initActions()
   editDelete = actionCollection()->addAction(QStringLiteral("edit_delete"));
   editDelete->setIcon(QIcon::fromTheme(QStringLiteral("delete-table-row")));
   editDelete->setText(i18n("&Delete Row"));
-  actionCollection()->setDefaultShortcut(editDelete, QKeySequence(Qt::CTRL + Qt::Key_K));
+  actionCollection()->setDefaultShortcut(editDelete, QKeySequence(Qt::CTRL | Qt::Key_K));
   editDelete->setWhatsThis(i18n("Deletes the selected row(s)"));
   editDelete->setToolTip(editDelete->whatsThis());
   editDelete->setStatusTip(editDelete->whatsThis());
@@ -207,7 +213,7 @@ void KWordQuizApp::initActions()
   editMarkBlank = actionCollection()->addAction(QStringLiteral("edit_mark_blank"));
   editMarkBlank->setIcon(QIcon::fromTheme(QStringLiteral("markasblank")));
   editMarkBlank->setText(i18n("&Mark as Blank"));
-  actionCollection()->setDefaultShortcut(editMarkBlank, QKeySequence(Qt::CTRL + Qt::Key_M));
+  actionCollection()->setDefaultShortcut(editMarkBlank, QKeySequence(Qt::CTRL | Qt::Key_M));
   editMarkBlank->setWhatsThis(i18n("Marks the current or selected word as a blank for Fill-in-the-blank"));
   editMarkBlank->setToolTip(editMarkBlank->whatsThis());
   editMarkBlank->setStatusTip(editMarkBlank->whatsThis());
@@ -224,7 +230,7 @@ void KWordQuizApp::initActions()
   vocabLanguages = actionCollection()->addAction(QStringLiteral("vocab_languages"));
   vocabLanguages->setIcon(QIcon::fromTheme(QStringLiteral("languages")));
   vocabLanguages->setText(i18n("&Column Settings..."));
-  actionCollection()->setDefaultShortcut(vocabLanguages, QKeySequence(Qt::CTRL + Qt::Key_L));
+  actionCollection()->setDefaultShortcut(vocabLanguages, QKeySequence(Qt::CTRL | Qt::Key_L));
   vocabLanguages->setWhatsThis(i18n("Defines the column settings for the active vocabulary"));
   vocabLanguages->setToolTip(vocabLanguages->whatsThis());
   vocabLanguages->setStatusTip(vocabLanguages->whatsThis());
@@ -381,7 +387,7 @@ void KWordQuizApp::initActions()
   qaHint = actionCollection()->addAction(QStringLiteral("qa_hint"));
   qaHint->setIcon(QIcon::fromTheme(QStringLiteral("hint")));
   qaHint->setText(i18n("&Hint"));
-  actionCollection()->setDefaultShortcut(qaHint, QKeySequence(Qt::CTRL + Qt::Key_H));
+  actionCollection()->setDefaultShortcut(qaHint, QKeySequence(Qt::CTRL | Qt::Key_H));
   qaHint->setWhatsThis(i18n("Gets the next correct letter of the answer"));
   qaHint->setToolTip(qaHint->whatsThis());
   qaHint->setStatusTip(qaHint->whatsThis());
@@ -389,7 +395,7 @@ void KWordQuizApp::initActions()
   qaMarkLastCorrect = actionCollection()->addAction(QStringLiteral("qa_mark_last_correct"));
   qaMarkLastCorrect->setIcon(QIcon::fromTheme(QStringLiteral("answer-correct")));
   qaMarkLastCorrect->setText(i18n("Mark Last Correct"));
-  actionCollection()->setDefaultShortcut(qaMarkLastCorrect, QKeySequence(Qt::SHIFT + Qt::Key_Return));
+  actionCollection()->setDefaultShortcut(qaMarkLastCorrect, QKeySequence(Qt::SHIFT | Qt::Key_Return));
   qaMarkLastCorrect->setWhatsThis(i18n("Marks last answer as correct"));
   qaMarkLastCorrect->setToolTip(qaMarkLastCorrect->whatsThis());
   qaMarkLastCorrect->setStatusTip(qaMarkLastCorrect->whatsThis());
@@ -397,7 +403,7 @@ void KWordQuizApp::initActions()
   quizRestart = actionCollection()->addAction(QStringLiteral("quiz_restart"));
   quizRestart->setIcon(QIcon::fromTheme(QStringLiteral("start-over")));
   quizRestart->setText(i18n("&Restart"));
-  actionCollection()->setDefaultShortcut(quizRestart, QKeySequence(Qt::CTRL + Qt::Key_R));
+  actionCollection()->setDefaultShortcut(quizRestart, QKeySequence(Qt::CTRL | Qt::Key_R));
   quizRestart->setWhatsThis(i18n("Restarts the quiz session from the beginning"));
   quizRestart->setToolTip(quizRestart->whatsThis());
   quizRestart->setStatusTip(quizRestart->whatsThis());
@@ -405,7 +411,7 @@ void KWordQuizApp::initActions()
   a = actionCollection()->addAction(QStringLiteral("quiz_audio_play"));
   a->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-start")));
   a->setText(i18n("&Play Audio"));
-  actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL + Qt::Key_B));
+  actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::Key_B));
   a->setWhatsThis(i18n("Play associated audio"));
   a->setToolTip(a->whatsThis());
   a->setStatusTip(a->whatsThis());
@@ -413,7 +419,7 @@ void KWordQuizApp::initActions()
   quizRepeatErrors = actionCollection()->addAction(QStringLiteral("quiz_repeat_errors"));
   quizRepeatErrors->setIcon(QIcon::fromTheme(QStringLiteral("repeat")));
   quizRepeatErrors->setText(i18n("Repeat &Errors"));
-  actionCollection()->setDefaultShortcut(quizRepeatErrors, QKeySequence(Qt::CTRL + Qt::Key_E));
+  actionCollection()->setDefaultShortcut(quizRepeatErrors, QKeySequence(Qt::CTRL | Qt::Key_E));
   quizRepeatErrors->setWhatsThis(i18n("Repeats all incorrectly answered questions"));
   quizRepeatErrors->setToolTip(quizRepeatErrors->whatsThis());
   quizRepeatErrors->setStatusTip(quizRepeatErrors->whatsThis());
@@ -822,13 +828,18 @@ void KWordQuizApp::slotFileOpenRecent(const QUrl &url)
 
 void KWordQuizApp::slotFileGHNS()
 {
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 78, 0)
   QPointer<KNS3::DownloadDialog> getHotNewStuffDialog = new KNS3::DownloadDialog(QStringLiteral("kwordquiz.knsrc"), this);
   getHotNewStuffDialog->exec();
   KNS3::Entry::List entries = getHotNewStuffDialog->changedEntries();
+#else
+  KNS3::QtQuickDialogWrapper dialog(QStringLiteral("kwordquiz.knsrc"));
+  const QList<KNSCore::EntryInternal> entries = dialog.exec();
+#endif
   QMimeDatabase db;
 
   // list of changed entries
-  foreach(const KNS3::Entry& entry, entries) {
+  foreach(const auto &entry, entries) {
     // check mime type and if kvtml, open it
     foreach(const QString &file, entry.installedFiles()) {
       QMimeType mimeType = db.mimeTypeForFile(file);
@@ -837,7 +848,6 @@ void KWordQuizApp::slotFileGHNS()
       }
     }
   }
-  delete getHotNewStuffDialog;
 }
 
 
